//// [parserGreaterThanTokenAmbiguity10.ts]
1 
// before
>>> // after
2;

//// [parserGreaterThanTokenAmbiguity10.js]
1
    >>>
        2;
